def slateblue():

    cor = 0x6A5ACD

    return cor

def slateblue1():

    cor = 0x836FFF

    return cor

def slateblue3():

    cor = 0x6959CD

    return cor

def darkslateblue():

    cor = 0x483D8B

    return cor

def midnightblue():

    cor = 0x191970

    return cor

def navy():

    cor = 0x000080

    return cor

def darkblue():

    cor = 0x00008B

    return cor

def mediumblue():

    cor = 0x0000CD

    return cor

def blue():

    cor = 0x0000FF

    return cor

def cornflowerblue():

    cor = 0x6495ED

    return cor

def royalblue():

    cor = 0x4169E1

    return cor

def dodgerblue():

    cor = 0x1E90FF

    return cor

def deepskyblue():

    cor = 0x00BFFF

    return cor

def lightskyblue():

    cor = 0x87CEFA

    return cor

def skyblue():

    cor = 0x87CEEB

    return cor

def lightblue():

    cor = 0xADD8E6

    return cor

def steelblue():

    cor = 0x4682B4

    return cor

def lightsteelblue():

    cor = 0xB0C4DE

    return cor

def slategray():

    cor = 0x708090

    return cor

def lightslategray():

    cor = 0x778899
    
    return cor