def darkslategreen():

    cor = 0x2F4F4F

    return cor

def mediumspringgreen():

    cor = 0x00FA9A

    return cor

def springgreen():

    cor = 0x00FF7F

    return cor

def palegreen():

    cor = 0x98FB98

    return cor

def lightgreen():

    cor = 0x90EE90

    return cor

def darkseagreen():

    cor = 0x8FBC8F

    return cor

def mediumseagreen():

    cor = 0x3CB371

    return cor

def seagreen():

    cor = 0x2E8B57

    return cor

def darkgreen():

    cor = 0x006400

    return cor

def green():

    cor = 0x008000

    return cor

def forestgreen():

    cor = 0x228B22

    return cor

def limegreen():

    cor = 0x32CD32

    return cor

def lime():

    cor = 0x00FF00

    return cor

def lawngreen():

    cor = 0x7CFC00

    return cor

def chartreuse():

    cor = 0x7FFF00

    return cor

def greenyellow():

    cor = 0xADFF2F

    return cor

def yellowgreen():

    cor = 0x9ACD32

    return cor

def olivedrab():

    cor = 0x6B8E23

    return cor

def darkolivegreen():

    cor = 0x556B2F

    return cor

def olive():

    cor = 0x808000

    return cor