def mediumslateBllue():

    cor = 0x7B68EE

    return cor

def mediumpurple():

    cor = 0x9370DB

    return cor

def blueviolet():

    cor = 0x8A2BE2

    return cor

def indigo():

    cor = 0x4B0082

    return cor

def darkviolet():

    cor = 0x9400D3

    return cor

def darkorchid():

    cor = 0x9932CC

    return cor

def mediumorchid():

    cor = 0xBA55D3

    return cor

def purple():

    cor = 0xA020F0

    return cor

def darkmagenta():

    cor = 0x8B008B

    return cor

def magenta():

    cor = 0xFF00FF

    return cor

def violet():

    cor = 0xEE82EE

    return cor

def orchid():

    cor = 0xDA70D6

    return cor

def plum():

    cor = 0xDDA0DD

    return cor