def darkkhaki():

    cor = 0xBDB76B

    return cor

def goldenrod():

    cor = 0xDAA520

    return cor

def darkgoldenrod():

    cor = 0xB8860B

    return cor

def saddlebrown():

    cor = 0x8B4513

    return cor

def sienna():

    cor = 0xA0522D

    return cor

def rosybrown():

    cor = 0xBC8F8F

    return cor

def peru():

    cor = 0xCD853F

    return cor

def chocolate():

    cor = 0xD2691E

    return cor

def sandybrown():

    cor = 0xF4A460

    return cor

def navajowhite():

    cor = 0xFFDEAD

    return cor

def wheat():

    cor = 0xF5DEB3

    return cor

def burlywood():

    cor = 0xDEB887

    return cor

def tan():

    cor = 0xD2B48C

    return cor