def mediumvioletred():

    cor = 0xC71585

    return cor

def deeppink():

    cor = 0xFF1493

    return cor

def hotpink():

    cor = 0xFF69B4

    return cor

def palevioletred():

    cor = 0xDB7093

    return cor

def lightpink():

    cor = 0xFFB6C1

    return cor

def pink():

    cor = 0xFFC0CB

    return cor

def lightcoral():

    cor = 0xF08080

    return cor

def indianred():

    cor = 0xCD5C5C

    return cor

def crimson():

    cor = 0xDC143C

    return cor